#
# spec file for package vboot
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define major_version 67
%define minor_version 10575
Name:           vboot
Version:        %{major_version}.%{minor_version}
Release:        lp152.3.56
Summary:        Chromium vboot
License:        BSD-3-Clause
Group:          Development/Tools/Other
URL:            https://git.chromium.org/git/chromiumos/platform/vboot_reference.git
# Source:         https://chromium.googlesource.com/chromiumos/platform/vboot_reference.git/+archive/release-R%{major_version}-%{minor_version}.B.tar.gz
Source:         release-R%{major_version}-%{minor_version}.B.tar.gz
# Disable static builds
Patch1:         fix_Makefile.patch
Patch2:         Fix-arch-detection-for-armv6.patch
BuildRequires:  gcc-c++
BuildRequires:  libgnutls-devel
BuildRequires:  libuuid-devel
BuildRequires:  libyaml-devel
BuildRequires:  python
BuildRequires:  trousers-devel
BuildRequires:  xz-devel
ExcludeArch:    ppc ppc64 ppc64le

%description
VBoot contains verified boot reference implementation and
helper tools for Chrome OS devices.

%prep
%setup -q -c
%patch1
%patch2 -p1

%build
export CFLAGS="-D_GNU_SOURCE %{optflags}"
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot}%{_prefix}
install -d -m 755 %{buildroot}/%{_datadir}/%{name}/devkeys/
cp -ar tests/devkeys/* %{buildroot}/%{_datadir}/%{name}/devkeys/

rm -f %{buildroot}%{_prefix}/default/vboot_reference
rm -f %{buildroot}%{_prefix}/lib/pkgconfig/vboot_host.pc

%files
%doc README LICENSE
%{_bindir}/bdb_extend
%{_bindir}/bmpblk_font
%{_bindir}/bmpblk_utility
%{_bindir}/chromeos-tpm-recovery
%{_bindir}/cgpt
%{_bindir}/common_minimal.sh
%{_bindir}/crossystem
%{_bindir}/dev_debug_vboot
%{_bindir}/dev_make_keypair
%{_bindir}/dumpRSAPublicKey
%{_bindir}/dump_fmap
%{_bindir}/dump_kernel_config
%{_bindir}/eficompress
%{_bindir}/efidecompress
%{_bindir}/enable_dev_usb_boot
%{_bindir}/futility
%{_bindir}/futility_s
%{_bindir}/gbb_flags_common.sh
%{_bindir}/gbb_utility
%{_bindir}/get_gbb_flags.sh
%{_bindir}/load_kernel_test
%{_bindir}/make_dev_firmware.sh
%{_bindir}/make_dev_ssd.sh
%{_bindir}/pad_digest_utility
%{_bindir}/resign_firmwarefd.sh
%{_bindir}/set_gbb_flags.sh
%{_bindir}/signature_digest_utility
%{_bindir}/tpm_init_temp_fix
%{_bindir}/tpm-nvsize
%{_bindir}/tpmc
%{_bindir}/vbutil_firmware
%{_bindir}/vbutil_kernel
%{_bindir}/vbutil_key
%{_bindir}/vbutil_keyblock
%{_bindir}/vbutil_what_keys
%{_bindir}/verify_data
%{_datadir}/%{name}

%changelog
* Mon Apr 30 2018 guillaume.gardet@opensuse.org
- Update to R67-10575:
  * Add new NV and GBB flag to control UDC
  * tpm_lite: tpmc command to check owner auth
  * tpm_lite: Add TlclGetSpaceInfo
  * tpm_lite: Add missing NVRAM attribute constant
  * tpm_lite: Support delegation family functional
  * tpm_lite: Add more general DefineSpaceEx funct
  * tpm_lite: Implement TakeOwnership support
  * tpm_lite: Implement ReadPubek command
  * cgpt: Remove hard coded 512 block size
  * tpm_lite: Introduce cursor read helpers
  * tpm_lite: Drop FOR_TEST for tlcl.c by
  * Add a script to generate a keypair for signing
  * crossystem: Clarify help string for dev_defaul
  * ec_sync: Go to recovery on aux fw update failu
  * ec_sync: Add recovery reason for aux update fa
  * firmware: tpm2_lite: fix command/response code
  * firmware: tpm2_lite: propagate actual errors
  * firmware: move TPM_E constants to tss_constant
  * Add GBB_FLAG_DISABLE_FWMP documentation to set
  * Add new GBB_FLAG_FORCE_MANUAL_RECOVERY
  * arc: Enable packages cache generation during s
  * crossystem: Fix mosys data length check by Ran
  * crossystem: Fix null pointer dereference on VM
  * firmware: remove unused vboot1 APIs
  * crossystem: add support for CNL gpiochip
  * 2lib: Add support for 64-byte nvstorage record
  * firmware: Remove deprecated SW_WP_ENABLED flag
* Wed Mar 14 2018 kasimir_@outlook.de
- Update to R66-10452
  * firmware: Remove VbLockDevice()
* Wed Mar  7 2018 kasimir_@outlook.de
- Update to R65-10323
  * EC-EFS: Copy dev keys from platform/ec
- removed obsolete Fix-arch-detection-for-aarch64.patch
- Add patch to enable armv6 build
  * Fix-arch-detection-for-armv6.patch
- Update fix_Makefile.patch
* Thu Jan 18 2018 guillaume@opensuse.org
- Remove full URL from Source since it breaks check script since a
  rename may happen (depending on web browser)
* Thu Jan 18 2018 guillaume@opensuse.org
- Exclude ppc and ppc64*
* Thu Jan 18 2018 guillaume@opensuse.org
- Update to R64-10176
* Tue Dec  5 2017 idonmez@suse.com
- Cleanup with spec-cleaner
* Mon Dec  4 2017 zombah@gmail.com
- add patch to enable aarch64 build
* Tue Nov 28 2017 guillaume@opensuse.org
- Switch from master to stable branches
- Remove _service and add tar.gz source
- Update to R63-10032 (fix build on Tumbleweed)
- Update fix_Makefile.patch
* Wed Jun 21 2017 zombah@gmail.com
- update specfile group and version
* Wed Jun 21 2017 zombah@gmail.com
- add c++ back
* Wed Jun 21 2017 zombah@gmail.com
- remove questinable dependencies
* Wed Jun 21 2017 zombah@gmail.com
- remove patch2-
* Wed Jun 21 2017 zombah@gmail.com
- remove sdl build requirement
* Wed Jun 21 2017 zombah@gmail.com
- add files lost with last commit
* Wed Jun 21 2017 zombah@gmail.com
- use obs service git hook
- update to version 20170302
- remove old parches and new
- update specfile
